# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),

## [Unreleased]

## [0.1.0] - 2021.06.24
### Added
- Generate Ingots package structure.
- Configure the `pre-commint` tool. See the `.pre-commit-config.yaml` config file for details.
- Configure the `tox` tool. See the `tox.ini` config file for details.
